import request from '@/utils/request'
import Qs from 'qs'

/**
 * 1.新增角色
 * 2.修改角色
 * 3.删除角色
 * 4.查询角色列表
 * 5.导出角色
 * -----------------
 * 6.查询角色详细
 * 7.角色数据权限
 * 8.角色状态修改
 * 9.查询角色下拉
 * */

// 1.新增角色
export function addRole(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/role/add',
    method: 'post',
    data: data,
    headers: {}
  })
}
// 2.修改角色
export function updateRole(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/role/update/' + businessId,
    method: 'put',
    data,
    headers: {}
  })
}
// 3.删除角色
export function delRole(roleId) {
  return request({
    url: '/system/role/deleteLogical/' + roleId,
    method: 'delete'
  })
}
// 4.查询角色列表
export function listRole(query) {
  return request({
    url: '/system/role/list',
    method: 'get',
    params: query
  })
}
// 5.导出角色
export function exportRole(query) {
  return request({
    url: '/system/role/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 6.查询角色详细
export function getRole(businessId) {
  return request({
    url: '/system/role/detail/' + businessId,
    method: 'get'
  })
}

// 7.角色数据权限
export function dataScope(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/role/dataScope',
    method: 'put',
    data,
    headers: {}
  })
}

// 8.角色状态修改
export function changeRoleStatus(businessId, flag) {
  const data = {
    businessId,
    flag
  }
  return request({
    url: '/system/role/changeStatus',
    method: 'put',
    params: data
  })
}

// 9.查询角色下拉
export function getListRole() {
  return request({
    url: 'system/role/listAll',
    method: 'get'
  })
}
